embassy-mcxa

Crates

git

Versions

mcx-a577

Flavors

get_and_clear_interrupt_spi5

Function get_and_clear_interrupt_spi5 

pub fn get_and_clear_interrupt_spi5() -> u32
Get current perf counter snapshot and reset the perf counter to zero

If the perf feature is not enabled, this always returns zero